import React, { useState, useEffect } from 'react';
import ReactDom from 'react-dom';
import { csv, arc, pie } from 'd3';
import { message } from './message';

const csvUrl =
  'https://gist.githubusercontent.com/Josh-Zalcman/f0ca70df0985ad120c994975b9d9f35d/raw/colors.csv';

const width = 960;
const height = 450;
const centerX = width / 2;
const centerY = height / 2;

const piArc = arc().innerRadius(0).outerRadius(width);

const App = () => {
  const [data, setData] = useState(null);
  const [color, setColor] = useState(null);

  useEffect(() => {
    csv(csvUrl).then((data) => {
      setData(data);
    });
  }, []);
  
  const handleMouseOver = (e)=>{
    setColor(e.target.id)
  }

  if (!data) {
    return <pre>Loading...</pre>;
  } else {
    return (
      <>
        <svg width={width} height={height}>
          <g transform={`translate(${centerX},${centerY})`}>
            {pie()
              .value(1)(data)
              .map((d) => (
                <path
                  id={d.data['Keyword']}
                  fill={d.data['RGB hex value']}
                  d={piArc(d)}
                  onMouseOver={handleMouseOver}
                />
              ))}
          </g>
        </svg>
        <div>{color}</div>
      </>
    );
  }
};

// {data.map((d, i) => (
//            <path
//              fill={d['RGB hex value']}
//              d={piArc({
//                startAngle: (i / data.length) * 2 * Math.PI,
//                endAngle:
//                  ((i + 1) / data.length) * 2 * Math.PI,
//              })}
//            />
//          ))}

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
